Construct a GEO landing page and open it directly in the system's default web
browser (or a user-specified browser). By default, this function uses the
brief amount of html format data for all entities.
Usage
geo_show(
accession,
famount = NULL,
scope = NULL,
ftp_over_https = NULL,
browser = getOption("browser")
)Arguments
- accession
A character of GEO accession IDs. Examples:
DataSets (GDS):
"GDS505","GDS606","GDS1234","GDS9999", etc.Series (GSE):
"GSE2","GSE22","GSE100","GSE2000", etc.Platforms (GPL):
"GPL96","GPL570","GPL10558", etc.Samples (GSM):
"GSM12345","GSM67890","GSM112233", etc.
- famount
A character specifying either:
the file
formaton the GEO FTP server, orthe
amountof data in the GEO Accession Display Bar.
See
geo_url()for details on theformatandamountarguments.- scope
A character specifying which GEO accessions to include (Only applicable to Accession Display Bar access).
"none": Applicable only to DataSets; for DataSets, this is also the sole valid option"self": the queried accession only."gsm","gpl","gse": related samples, platforms, or series."all": all accessions related to the query (family view).
- ftp_over_https
Logical scalar. If
TRUE, connects to GEO FTP server via HTTPS (https://ftp.ncbi.nlm.nih.gov/geo); otherwise uses plain FTP (ftp://ftp.ncbi.nlm.nih.gov/geo). Only applicable to GEO FTP server access.- browser
a non-empty character string giving the name of the program to be used as the HTML browser. It should be in the PATH, or a full path specified. Alternatively, an R function to be called to invoke the browser.
Under Windows
NULLis also allowed (and is the default), and implies that the file association mechanism will be used.
Details
See browseURL()
Examples
if (interactive()) {
geo_show("gpl96")
}